@@ -323,7 +323,34 @@ class IgSession(Session):
                 f"Market id '{market_id}' is not valid. Use 'market details' API to find the market id."
             )
 
-        return float(r.json()["longPositionPercentage"]) / 100
+        return r.json()["longPositionPercentage"] / 100
+
+    def sentiments(self, market_ids: List[str]) -> Dict[str, float]:
+        assert isinstance(market_ids, List)
+        assert market_ids
+
+        sentiment_url = self._master_url + f"clientsentiment"
+        params = {"marketIds": ','.join(market_ids)}
+
+        r = self._request_retry_allowance(
+            requests.get, url=sentiment_url, headers=self._headers, params=params
+        )
+        assert r.status_code == 200, (r.status_code, r.text)
+
+        result = {}
+        for el in r.json()["clientSentiments"]:
+            mkt_id = el["marketId"]
+            if (
+                    (long := el["longPositionPercentage"])
+                    == el["shortPositionPercentage"]
+                    == 0.0
+            ):
+                raise MarketNotFoundError(
+                    f"Market id '{mkt_id}' is not valid. Use 'market details' API to find the market id."
+                )
+            result[mkt_id] = long
+
+        return result
 
     def _login(self, identifier, password):
         login_url = self._master_url + "session"
